@@ -6,7 +6,13 @@ fn criterion_benchmark(c: &mut Bencher) {
     c.iter(|| {
         let data = include_bytes!("../tests/data/certificate.chain.pem");
         let mut reader = BufReader::new(&data[..]);
-        assert_eq!(rustls_pemfile::certs(&mut reader).unwrap().len(), 3);
+        assert_eq!(
+            rustls_pemfile::certs(&mut reader)
+                .collect::<Result<Vec<_>, _>>()
+                .unwrap()
+                .len(),
+            3
+        );
     });
 }
 
